@@ -6,6 +6,7 @@ import com.badlogic.gdx.utils.Json
 import com.badlogic.gdx.utils.JsonWriter
 import com.badlogic.gdx.utils.SerializationException
 import com.unciv.logic.civilization.CivRankingHistory
+import com.unciv.logic.civilization.Notification
 import com.unciv.logic.map.tile.TileHistory
 import com.unciv.ui.components.input.KeyCharAndCode
 import com.unciv.ui.components.input.KeyboardBindings
@@ -29,6 +30,7 @@ fun json() = Json(JsonWriter.OutputType.json).apply {
     setSerializer(KeyboardBindings::class.java, KeyboardBindings.Serializer())
     setSerializer(TileHistory::class.java, TileHistory.Serializer())
     setSerializer(CivRankingHistory::class.java, CivRankingHistory.Serializer())
+    setSerializer(Notification::class.java, Notification.Serializer())
 }
 
 /**
