@@ -269,7 +269,7 @@ object UnitAutomation {
 
         if (unit.hasUnique(UniqueType.MayFoundReligion)
                 && unit.civ.religionManager.religionState < ReligionState.Religion
-                && unit.civ.religionManager.mayFoundReligionAtAll(unit)
+                && unit.civ.religionManager.mayFoundReligionAtAll()
         )
             return SpecificUnitAutomation.foundReligion(unit)
 
@@ -303,12 +303,8 @@ object UnitAutomation {
         val isLateGame = isLateGame(unit.civ)
         // Great scientist -> Hurry research if late game
         if (isLateGame) {
-            val hurryResearch = UnitActions.getUnitActions(unit)
-                .firstOrNull { it.type == UnitActionType.HurryResearch }?.action
-            if (hurryResearch != null) {
-                hurryResearch()
-                return
-            }
+            val hurriedResearch = UnitActions.invokeUnitAction(unit, UnitActionType.HurryResearch)
+            if (hurriedResearch) return
         }
 
         // Great merchant -> Conduct trade mission if late game and if not at war.
@@ -345,7 +341,7 @@ object UnitAutomation {
             val improvementCanBePlacedEventually =
                     SpecificUnitAutomation.automateImprovementPlacer(unit)
             if (!improvementCanBePlacedEventually)
-                startGoldenAgeIfHasAbility(unit)
+                UnitActions.invokeUnitAction(unit, UnitActionType.StartGoldenAge)
         }
 
         // TODO: The AI tends to have a lot of great generals. Maybe there should be a cutoff
@@ -361,10 +357,6 @@ object UnitAutomation {
         return researchCompletePercent >= 0.8f
     }
 
-    private fun startGoldenAgeIfHasAbility(unit: MapUnit) {
-        UnitActions.getUnitActions(unit).firstOrNull { it.type == UnitActionType.StartGoldenAge }?.action?.invoke()
-    }
-
     /** @return true only if the unit has 0 movement left */
     private fun tryAttacking(unit: MapUnit): Boolean {
         repeat(unit.maxAttacksPerTurn() - unit.attacksThisTurn) {
@@ -462,7 +454,7 @@ object UnitAutomation {
         val unitDistanceToTiles = unit.movement.getDistanceToTiles()
         val tilesThatCanWalkToAndThenPillage = unitDistanceToTiles
             .filter { it.value.totalDistance < unit.currentMovement }.keys
-            .filter { unit.movement.canMoveTo(it) && UnitActions.canPillage(unit, it)
+            .filter { unit.movement.canMoveTo(it) && UnitActionsPillage.canPillage(unit, it)
                     && (it.canPillageTileImprovement()
                     || (it.canPillageRoad() && it.getRoadOwner() != null && unit.civ.isAtWarWith(it.getRoadOwner()!!)))}
 
