@@ -4,7 +4,6 @@ import com.badlogic.gdx.math.Vector2
 import com.unciv.Constants
 import com.unciv.UncivGame
 import com.unciv.logic.automation.civilization.NextTurnAutomation
-import com.unciv.logic.automation.unit.SpecificUnitAutomation
 import com.unciv.logic.city.City
 import com.unciv.logic.civilization.AlertType
 import com.unciv.logic.civilization.Civilization
@@ -15,25 +14,19 @@ import com.unciv.logic.civilization.NotificationIcon
 import com.unciv.logic.civilization.PlayerType
 import com.unciv.logic.civilization.PopupAlert
 import com.unciv.logic.civilization.PromoteUnitAction
-import com.unciv.logic.civilization.diplomacy.DiplomaticModifiers
-import com.unciv.logic.civilization.diplomacy.DiplomaticStatus
 import com.unciv.logic.map.mapunit.MapUnit
-import com.unciv.logic.map.tile.RoadStatus
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.UnitActionType
-import com.unciv.models.helpers.UnitMovementMemoryType
 import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.Unique
 import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.stats.Stat
 import com.unciv.models.stats.Stats
-import com.unciv.ui.components.extensions.toPercent
-import com.unciv.ui.screens.worldscreen.bottombar.BattleTable
+import com.unciv.ui.components.UnitMovementMemoryType
 import com.unciv.utils.debug
 import kotlin.math.max
 import kotlin.math.min
-import kotlin.math.ulp
 import kotlin.random.Random
 
 /**
@@ -91,7 +84,7 @@ object Battle {
      */
     fun attackOrNuke(attacker: ICombatant, attackableTile: AttackableTile): DamageDealt {
         return if (attacker is MapUnitCombatant && attacker.unit.baseUnit.isNuclearWeapon()) {
-            NUKE(attacker, attackableTile.tileToAttack)
+            Nuke.NUKE(attacker, attackableTile.tileToAttack)
             DamageDealt.None
         } else {
             attack(attacker, getMapCombatantOfTile(attackableTile.tileToAttack)!!)
@@ -113,7 +106,7 @@ object Battle {
 
         val interceptDamage: DamageDealt
         if (attacker is MapUnitCombatant && attacker.unit.baseUnit.isAirUnit()) {
-            interceptDamage = tryInterceptAirAttack(attacker, attackedTile, defender.getCivInfo(), defender)
+            interceptDamage = AirInterception.tryInterceptAirAttack(attacker, attackedTile, defender.getCivInfo(), defender)
             if (attacker.isDefeated()) return interceptDamage
         } else interceptDamage = DamageDealt.None
 
@@ -363,7 +356,7 @@ object Battle {
         }
     }
 
-    private fun takeDamage(attacker: ICombatant, defender: ICombatant): DamageDealt {
+    internal fun takeDamage(attacker: ICombatant, defender: ICombatant): DamageDealt {
         var potentialDamageToDefender = BattleDamage.calculateDamageToDefender(attacker, defender)
         var potentialDamageToAttacker = BattleDamage.calculateDamageToAttacker(attacker, defender)
 
@@ -438,7 +431,7 @@ object Battle {
         }
     }
 
-    private fun postBattleNotifications(
+    internal fun postBattleNotifications(
         attacker: ICombatant,
         defender: ICombatant,
         attackedTile: Tile,
@@ -543,7 +536,7 @@ object Battle {
     }
 
     // XP!
-    private fun addXp(thisCombatant: ICombatant, amount: Int, otherCombatant: ICombatant) {
+    internal fun addXp(thisCombatant: ICombatant, amount: Int, otherCombatant: ICombatant) {
         if (thisCombatant !is MapUnitCombatant) return
         val civ = thisCombatant.getCivInfo()
         val otherIsBarbarian = otherCombatant.getCivInfo().isBarbarian()
@@ -625,9 +618,7 @@ object Battle {
         } else if (attackerCiv.isHuman()) {
             // we're not taking our former capital
             attackerCiv.popupAlerts.add(PopupAlert(AlertType.CityConquered, city.id))
-        } else {
-            NextTurnAutomation.onConquerCity(attackerCiv, city)
-        }
+        } else  automateCityConquer(attackerCiv, city)
 
         if (attackerCiv.isCurrentPlayer())
             UncivGame.Current.settings.addCompletedTutorialTask("Conquer a city")
@@ -637,6 +628,31 @@ object Battle {
             UniqueTriggerActivation.triggerCivwideUnique(unique, attackerCiv, city)
     }
 
+    /** Handle decision making after city conquest, namely whether the AI should liberate, puppet,
+     * or raze a city */
+    private fun automateCityConquer(civInfo: Civilization, city: City) {
+        if (!city.hasDiplomaticMarriage()) {
+            val foundingCiv = civInfo.gameInfo.getCivilization(city.foundingCiv)
+            var valueAlliance = NextTurnAutomation.valueCityStateAlliance(civInfo, foundingCiv)
+            if (civInfo.getHappiness() < 0)
+                valueAlliance -= civInfo.getHappiness() // put extra weight on liberating if unhappy
+            if (foundingCiv.isCityState() && city.civ != civInfo && foundingCiv != civInfo
+                && !civInfo.isAtWarWith(foundingCiv)
+                && valueAlliance > 0) {
+                city.liberateCity(civInfo)
+                return
+            }
+        }
+
+        city.puppetCity(civInfo)
+        if ((city.population.population < 4 || civInfo.isCityState())
+            && city.foundingCiv != civInfo.civName && city.canBeDestroyed(justCaptured = true)) {
+            // raze if attacker is a city state
+            if (!civInfo.hasUnique(UniqueType.MayNotAnnexCities)) city.annexCity()
+            city.isBeingRazed = true
+        }
+    }
+
     fun getMapCombatantOfTile(tile: Tile): ICombatant? {
         if (tile.isCityCenter()) return CityCombatant(tile.getCity()!!)
         if (tile.militaryUnit != null) return MapUnitCombatant(tile.militaryUnit!!)
@@ -750,397 +766,6 @@ object Battle {
         }
     }
 
-    /**
-     *  Checks whether [nuke] is allowed to nuke [targetTile]
-     *  - Not if we would need to declare war on someone we can't.
-     *  - Disallow nuking the tile the nuke is in, as per Civ5 (but not nuking your own tiles/units otherwise)
-     *
-     *  Both [BattleTable.simulateNuke] and [SpecificUnitAutomation.automateNukes] check range, so that check is omitted here.
-     */
-    fun mayUseNuke(nuke: MapUnitCombatant, targetTile: Tile): Boolean {
-        if (nuke.getTile() == targetTile) return false
-        // Can only nuke visible Tiles
-        if (!targetTile.isVisible(nuke.getCivInfo())) return false
-
-        var canNuke = true
-        val attackerCiv = nuke.getCivInfo()
-        fun checkDefenderCiv(defenderCiv: Civilization?) {
-            if (defenderCiv == null) return
-            // Allow nuking yourself! (Civ5 source: CvUnit::isNukeVictim)
-            if (defenderCiv == attackerCiv || defenderCiv.isDefeated()) return
-            // Gleaned from Civ5 source - this disallows nuking unknown civs even in invisible tiles
-            // https://github.com/Gedemon/Civ5-DLL/blob/master/CvGameCoreDLL_Expansion1/CvUnit.cpp#L5056
-            // https://github.com/Gedemon/Civ5-DLL/blob/master/CvGameCoreDLL_Expansion1/CvTeam.cpp#L986
-            if (attackerCiv.knows(defenderCiv) && attackerCiv.getDiplomacyManager(defenderCiv).canAttack())
-                return
-            canNuke = false
-        }
-
-        val blastRadius = nuke.unit.getNukeBlastRadius()
-        for (tile in targetTile.getTilesInDistance(blastRadius)) {
-            checkDefenderCiv(tile.getOwner())
-            checkDefenderCiv(getMapCombatantOfTile(tile)?.getCivInfo())
-        }
-        return canNuke
-    }
-
-    @Suppress("FunctionName")   // Yes we want this name to stand out
-    fun NUKE(attacker: MapUnitCombatant, targetTile: Tile) {
-        val attackingCiv = attacker.getCivInfo()
-        fun tryDeclareWar(civSuffered: Civilization) {
-            if (civSuffered != attackingCiv
-                && civSuffered.knows(attackingCiv)
-                && civSuffered.getDiplomacyManager(attackingCiv).diplomaticStatus != DiplomaticStatus.War
-            ) {
-                attackingCiv.getDiplomacyManager(civSuffered).declareWar()
-                attackingCiv.addNotification("After being hit by our [${attacker.getName()}], [${civSuffered}] has declared war on us!", targetTile.position, NotificationCategory.Diplomacy, NotificationIcon.War)
-            }
-        }
-
-        val nukeStrength = attacker.unit.getMatchingUniques(UniqueType.NuclearWeapon)
-            .firstOrNull()?.params?.get(0)?.toInt() ?: return
-
-        val blastRadius = attacker.unit.getMatchingUniques(UniqueType.BlastRadius)
-            .firstOrNull()?.params?.get(0)?.toInt() ?: 2
-
-        // Calculate the tiles that are hit
-        val hitTiles = targetTile.getTilesInDistance(blastRadius)
-
-        // Declare war on the owners of all hit tiles
-        for (hitCiv in hitTiles.mapNotNull { it.getOwner() }.distinct()) {
-            hitCiv.addNotification("A(n) [${attacker.getName()}] exploded in our territory!", targetTile.position, NotificationCategory.War, NotificationIcon.War)
-            tryDeclareWar(hitCiv)
-        }
-
-        // Declare war on all potentially hit units. They'll try to intercept the nuke before it drops
-        for (civWhoseUnitWasAttacked in hitTiles
-            .flatMap { it.getUnits() }
-            .map { it.civ }.distinct()
-            .filter { it != attackingCiv }) {
-                tryDeclareWar(civWhoseUnitWasAttacked)
-                if (attacker.unit.baseUnit.isAirUnit() && !attacker.isDefeated()) {
-                    tryInterceptAirAttack(attacker, targetTile, civWhoseUnitWasAttacked, null)
-            }
-        }
-        if (attacker.isDefeated()) return
-
-        attacker.unit.attacksSinceTurnStart.add(Vector2(targetTile.position))
-
-        for (tile in hitTiles) {
-            // Handle complicated effects
-            doNukeExplosionForTile(attacker, tile, nukeStrength, targetTile == tile)
-        }
-
-        // Instead of postBattleAction() just destroy the unit, all other functions are not relevant
-        if (attacker.unit.hasUnique(UniqueType.SelfDestructs)) attacker.unit.destroy()
-
-        // It's unclear whether using nukes results in a penalty with all civs, or only affected civs.
-        // For now I'll make it give a diplomatic penalty to all known civs, but some testing for this would be appreciated
-        for (civ in attackingCiv.getKnownCivs()) {
-            civ.getDiplomacyManager(attackingCiv).setModifier(DiplomaticModifiers.UsedNuclearWeapons, -50f)
-        }
-
-        if (!attacker.isDefeated()) {
-            attacker.unit.attacksThisTurn += 1
-        }
-    }
-
-    private fun doNukeExplosionForTile(
-        attacker: MapUnitCombatant,
-        tile: Tile,
-        nukeStrength: Int,
-        isGroundZero: Boolean
-    ) {
-        // https://forums.civfanatics.com/resources/unit-guide-modern-future-units-g-k.25628/
-        // https://www.carlsguides.com/strategy/civilization5/units/aircraft-nukes.ph
-        // Testing done by Ravignir
-        // original source code: GenerateNuclearExplosionDamage(), ApplyNuclearExplosionDamage()
-
-        var damageModifierFromMissingResource = 1f
-        val civResources = attacker.getCivInfo().getCivResourcesByName()
-        for (resource in attacker.unit.baseUnit.getResourceRequirementsPerTurn().keys) {
-            if (civResources[resource]!! < 0 && !attacker.getCivInfo().isBarbarian())
-                damageModifierFromMissingResource *= 0.5f // I could not find a source for this number, but this felt about right
-                // - Original Civ5 does *not* reduce damage from missing resource, from source inspection
-        }
-
-        var buildingModifier = 1f  // Strange, but in Civ5 a bunker mitigates damage to garrison, even if the city is destroyed by the nuke
-
-        // Damage city and reduce its population
-        val city = tile.getCity()
-        if (city != null && tile.position == city.location) {
-            buildingModifier = city.getAggregateModifier(UniqueType.GarrisonDamageFromNukes)
-            doNukeExplosionDamageToCity(city, nukeStrength, damageModifierFromMissingResource)
-            postBattleNotifications(attacker, CityCombatant(city), city.getCenterTile())
-            destroyIfDefeated(city.civ, attacker.getCivInfo())
-        }
-
-        // Damage and/or destroy units on the tile
-        for (unit in tile.getUnits().toList()) { // toList so if it's destroyed there's no concurrent modification
-            val damage = (when {
-                    isGroundZero || nukeStrength >= 2 -> 100
-                    // The following constants are NUKE_UNIT_DAMAGE_BASE / NUKE_UNIT_DAMAGE_RAND_1 / NUKE_UNIT_DAMAGE_RAND_2 in Civ5
-                    nukeStrength == 1 -> 30 + Random.Default.nextInt(40) + Random.Default.nextInt(40)
-                    // Level 0 does not exist in Civ5 (it treats units same as level 2)
-                    else -> 20 + Random.Default.nextInt(30)
-                } * buildingModifier * damageModifierFromMissingResource + 1f.ulp).toInt()
-            val defender = MapUnitCombatant(unit)
-            if (unit.isCivilian()) {
-                if (unit.health - damage <= 40) unit.destroy()  // Civ5: NUKE_NON_COMBAT_DEATH_THRESHOLD = 60
-            } else {
-                defender.takeDamage(damage)
-            }
-            postBattleNotifications(attacker, defender, defender.getTile())
-            destroyIfDefeated(defender.getCivInfo(), attacker.getCivInfo())
-        }
-
-        // Pillage improvements, pillage roads, add fallout
-        if (tile.isCityCenter()) return  // Never touch city centers - if they survived
-        fun applyPillageAndFallout() {
-            if (tile.getUnpillagedImprovement() != null && !tile.getTileImprovement()!!.hasUnique(UniqueType.Irremovable)) {
-                if (tile.getTileImprovement()!!.hasUnique(UniqueType.Unpillagable)) {
-                    tile.removeImprovement()
-                } else {
-                    tile.setPillaged()
-                }
-            }
-            if (tile.getUnpillagedRoad() != RoadStatus.None)
-                tile.setPillaged()
-            if (tile.isWater || tile.isImpassible() || tile.terrainFeatures.contains("Fallout")) return
-            tile.addTerrainFeature("Fallout")
-        }
-
-        if (tile.terrainHasUnique(UniqueType.DestroyableByNukesChance)) {
-            // Note: Safe from concurrent modification exceptions only because removeTerrainFeature
-            // *replaces* terrainFeatureObjects and the loop will continue on the old one
-            for (terrainFeature in tile.terrainFeatureObjects) {
-                for (unique in terrainFeature.getMatchingUniques(UniqueType.DestroyableByNukesChance)) {
-                    val chance = unique.params[0].toFloat() / 100f
-                    if (!(chance > 0f && isGroundZero) && Random.Default.nextFloat() >= chance) continue
-                    tile.removeTerrainFeature(terrainFeature.name)
-                    applyPillageAndFallout()
-                }
-            }
-        } else if (isGroundZero || Random.Default.nextFloat() < 0.5f) {  // Civ5: NUKE_FALLOUT_PROB
-            applyPillageAndFallout()
-        }
-    }
-
-    /** @return the "protection" modifier from buildings (Bomb Shelter, UniqueType.PopulationLossFromNukes) */
-    private fun doNukeExplosionDamageToCity(targetedCity: City, nukeStrength: Int, damageModifierFromMissingResource: Float) {
-        // Original Capitals must be protected, `canBeDestroyed` is responsible for that check.
-        // The `justCaptured = true` parameter is what allows other Capitals to suffer normally.
-        if ((nukeStrength > 2 || nukeStrength > 1 && targetedCity.population.population < 5)
-                && targetedCity.canBeDestroyed(true)) {
-            targetedCity.destroyCity()
-            return
-        }
-
-        val cityCombatant = CityCombatant(targetedCity)
-        cityCombatant.takeDamage((cityCombatant.getHealth() * 0.5f * damageModifierFromMissingResource).toInt())
-
-        // Difference to original: Civ5 rounds population loss down twice - before and after bomb shelters
-        val populationLoss = (
-                targetedCity.population.population *
-                    targetedCity.getAggregateModifier(UniqueType.PopulationLossFromNukes) *
-                when (nukeStrength) {
-                    0 -> 0f
-                    1 -> (30 + Random.Default.nextInt(20) + Random.Default.nextInt(20)) / 100f
-                    2 -> (60 + Random.Default.nextInt(10) + Random.Default.nextInt(10)) / 100f
-                    else -> 1f  // hypothetical nukeStrength 3 -> always to 1 pop
-                }
-            ).toInt().coerceAtMost(targetedCity.population.population - 1)
-        targetedCity.population.addPopulation(-populationLoss)
-    }
-
-    private fun City.getAggregateModifier(uniqueType: UniqueType): Float {
-        var modifier = 1f
-        for (unique in getMatchingUniques(uniqueType)) {
-            if (!matchesFilter(unique.params[1])) continue
-            modifier *= unique.params[0].toPercent()
-        }
-        return modifier
-    }
-
-    // Should draw an Interception if available on the tile from any Civ
-    // Land Units deal 0 damage, and no XP for either party
-    // Air Interceptors do Air Combat as if Melee (mutual damage) but using Ranged Strength. 5XP to both
-    // But does not use the Interception mechanic bonuses/promotions
-    // Counts as an Attack for both units
-    // Will always draw out an Interceptor's attack (they cannot miss)
-    // This means the combat against Air Units will execute and always deal damage
-    // Random Civ at War will Intercept, prioritizing Air Units,
-    // sorted by highest Intercept chance (same as regular Intercept)
-    fun airSweep(attacker: MapUnitCombatant, attackedTile: Tile) {
-        // Air Sweep counts as an attack, even if nothing else happens
-        attacker.unit.attacksThisTurn++
-        // copied and modified from reduceAttackerMovementPointsAndAttacks()
-        // use up movement
-        if (attacker.unit.hasUnique(UniqueType.CanMoveAfterAttacking) || attacker.unit.maxAttacksPerTurn() > attacker.unit.attacksThisTurn) {
-            // if it was a melee attack and we won, then the unit ALREADY got movement points deducted,
-            // for the movement to the enemy's tile!
-            // and if it's an air unit, it only has 1 movement anyway, so...
-            if (!attacker.unit.baseUnit.movesLikeAirUnits())
-                attacker.unit.useMovementPoints(1f)
-        } else attacker.unit.currentMovement = 0f
-        val attackerName = attacker.getName()
-
-        // Make giant sequence of all potential Interceptors from all Civs isAtWarWith()
-        var potentialInterceptors = sequence<MapUnit> {  }
-        for (interceptingCiv in UncivGame.Current.gameInfo!!.civilizations
-            .filter {attacker.getCivInfo().isAtWarWith(it)}) {
-            potentialInterceptors += interceptingCiv.units.getCivUnits()
-                .filter { it.canIntercept(attackedTile) }
-        }
-
-        // first priority, only Air Units
-        if (potentialInterceptors.any { it.baseUnit.isAirUnit() })
-            potentialInterceptors = potentialInterceptors.filter { it.baseUnit.isAirUnit() }
-
-        // Pick highest chance interceptor
-        for (interceptor in potentialInterceptors
-            .shuffled()  // randomize Civ
-            .sortedByDescending { it.interceptChance() }) {
-            // No chance of Interceptor to miss (unlike regular Interception). Always want to deal damage
-            val interceptingCiv = interceptor.civ
-            val interceptorName = interceptor.name
-            // pairs of LocationAction for Notification
-            val locations = LocationAction(
-                interceptor.currentTile.position,
-                attacker.unit.currentTile.position
-            )
-            val locationsInterceptorUnknown =
-                    LocationAction(attackedTile.position, attacker.unit.currentTile.position)
-
-            interceptor.attacksThisTurn++  // even if you miss, you took the shot
-            val damageDealt: DamageDealt
-            if (!interceptor.baseUnit.isAirUnit()) {
-                // Deal no damage (moddable in future?) and no XP
-                val attackerText =
-                        "Our [$attackerName] ([-0] HP) was attacked by an intercepting [$interceptorName] ([-0] HP)"
-                val interceptorText =
-                        "Our [$interceptorName] ([-0] HP) intercepted and attacked an enemy [$attackerName] ([-0] HP)"
-                attacker.getCivInfo().addNotification(
-                    attackerText, locations, NotificationCategory.War,
-                    attackerName, NotificationIcon.War, interceptorName
-                )
-                interceptingCiv.addNotification(
-                    interceptorText, locations, NotificationCategory.War,
-                    interceptorName, NotificationIcon.War, attackerName
-                )
-                attacker.unit.action = null
-                return
-            } else {
-                // Damage if Air v Air should work similar to Melee
-                damageDealt = takeDamage(attacker, MapUnitCombatant(interceptor))
-
-                // 5 XP to both
-                addXp(MapUnitCombatant(interceptor), 5, attacker)
-                addXp(attacker, 5, MapUnitCombatant(interceptor))
-            }
-
-            val attackerText =
-                    if (attacker.isDefeated()) {
-                        if (interceptor.getTile() in attacker.getCivInfo().viewableTiles)
-                            "Our [$attackerName] ([-${damageDealt.defenderDealt}] HP) was destroyed by an intercepting [$interceptorName] ([-${damageDealt.attackerDealt}] HP)"
-                        else "Our [$attackerName] ([-${damageDealt.defenderDealt}] HP) was destroyed by an unknown interceptor"
-                    } else if (MapUnitCombatant(interceptor).isDefeated()) {
-                        "Our [$attackerName] ([-${damageDealt.defenderDealt}] HP) destroyed an intercepting [$interceptorName] ([-${damageDealt.attackerDealt}] HP)"
-                    } else "Our [$attackerName] ([-${damageDealt.defenderDealt}] HP) was attacked by an intercepting [$interceptorName] ([-${damageDealt.attackerDealt}] HP)"
-
-            attacker.getCivInfo().addNotification(
-                attackerText, locationsInterceptorUnknown, NotificationCategory.War,
-                attackerName, NotificationIcon.War, NotificationIcon.Question
-            )
-
-            val interceptorText =
-                    if (attacker.isDefeated())
-                        "Our [$interceptorName] ([-${damageDealt.attackerDealt}] HP) intercepted and destroyed an enemy [$attackerName] ([-${damageDealt.defenderDealt}] HP)"
-                    else if (MapUnitCombatant(interceptor).isDefeated()) {
-                        if (attacker.getTile() in interceptingCiv.viewableTiles) "Our [$interceptorName] ([-${damageDealt.attackerDealt}] HP) intercepted and was destroyed by an enemy [$attackerName] ([-${damageDealt.defenderDealt}] HP)"
-                        else "Our [$interceptorName] ([-${damageDealt.attackerDealt}] HP) intercepted and was destroyed by an unknown enemy"
-                    } else "Our [$interceptorName] ([-${damageDealt.attackerDealt}] HP) intercepted and attacked an enemy [$attackerName] ([-${damageDealt.defenderDealt}] HP)"
-
-            interceptingCiv.addNotification(
-                interceptorText, locations, NotificationCategory.War,
-                interceptorName, NotificationIcon.War, attackerName
-            )
-            attacker.unit.action = null
-            return
-        }
-
-        // No Interceptions available
-        val attackerText = "Nothing tried to intercept our [$attackerName]"
-        attacker.getCivInfo().addNotification(attackerText, NotificationCategory.War, attackerName)
-        attacker.unit.action = null
-    }
-
-    private fun tryInterceptAirAttack(
-        attacker: MapUnitCombatant,
-        attackedTile: Tile,
-        interceptingCiv: Civilization,
-        defender: ICombatant?
-    ): DamageDealt {
-        if (attacker.unit.hasUnique(UniqueType.CannotBeIntercepted, StateForConditionals(attacker.getCivInfo(), ourCombatant = attacker, theirCombatant = defender, attackedTile = attackedTile)))
-            return DamageDealt.None
-
-        // Pick highest chance interceptor
-        val interceptor = interceptingCiv.units.getCivUnits()
-            .filter { it.canIntercept(attackedTile) }
-            .sortedByDescending { it.interceptChance() }
-            .firstOrNull { unit ->
-                // Can't intercept if we have a unique preventing it
-                val conditionalState = StateForConditionals(interceptingCiv, ourCombatant = MapUnitCombatant(unit), theirCombatant = attacker, combatAction = CombatAction.Intercept, attackedTile = attackedTile)
-                unit.getMatchingUniques(UniqueType.CannotInterceptUnits, conditionalState)
-                    .none { attacker.matchesCategory(it.params[0]) }
-                // Defender can't intercept either
-                && unit != (defender as? MapUnitCombatant)?.unit
-            }
-            ?: return DamageDealt.None
-
-        interceptor.attacksThisTurn++  // even if you miss, you took the shot
-        // Does Intercept happen? If not, exit
-        if (Random.Default.nextFloat() > interceptor.interceptChance() / 100f)
-            return DamageDealt.None
-
-        var damage = BattleDamage.calculateDamageToDefender(
-            MapUnitCombatant(interceptor),
-            attacker
-        )
-
-        var damageFactor = 1f + interceptor.interceptDamagePercentBonus().toFloat() / 100f
-        damageFactor *= attacker.unit.receivedInterceptDamageFactor()
-
-        damage = (damage.toFloat() * damageFactor).toInt().coerceAtMost(attacker.unit.health)
-
-        attacker.takeDamage(damage)
-        if (damage > 0)
-            addXp(MapUnitCombatant(interceptor), 2, attacker)
-
-        val attackerName = attacker.getName()
-        val interceptorName = interceptor.name
-        val locations = LocationAction(interceptor.currentTile.position, attacker.unit.currentTile.position)
-
-        val attackerText = if (!attacker.isDefeated())
-            "Our [$attackerName] ([-$damage] HP) was attacked by an intercepting [$interceptorName] ([-0] HP)"
-        else if (interceptor.getTile() in attacker.getCivInfo().viewableTiles)
-            "Our [$attackerName] ([-$damage] HP) was destroyed by an intercepting [$interceptorName] ([-0] HP)"
-        else "Our [$attackerName] ([-$damage] HP) was destroyed by an unknown interceptor"
-
-        attacker.getCivInfo().addNotification(
-            attackerText, interceptor.currentTile.position, NotificationCategory.War,
-            attackerName, NotificationIcon.War, interceptorName
-        )
-
-        val interceptorText = if (attacker.isDefeated())
-            "Our [$interceptorName] ([-0] HP) intercepted and destroyed an enemy [$attackerName] ([-$damage] HP)"
-        else "Our [$interceptorName] ([-0] HP) intercepted and attacked an enemy [$attackerName] ([-$damage] HP)"
-        interceptingCiv.addNotification(interceptorText, locations, NotificationCategory.War,
-                interceptorName, NotificationIcon.War, attackerName)
-
-        return DamageDealt(0, damage)
-    }
-
     private fun doWithdrawFromMeleeAbility(attacker: ICombatant, defender: ICombatant, baseWithdrawChance: Int): Boolean {
         if (baseWithdrawChance == 0) return false
         // Some notes...
