@@ -8,7 +8,7 @@ import com.unciv.logic.city.City
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.civilization.managers.ReligionState
 import com.unciv.models.ruleset.Ruleset
-import com.unciv.models.ruleset.validation.RulesetValidator
+import com.unciv.models.ruleset.validation.UniqueValidator
 import com.unciv.models.stats.Stats
 import com.unciv.models.translations.getConditionals
 import com.unciv.models.translations.getPlaceholderParameters
@@ -21,7 +21,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
      *  - for instance, in the city screen, we call every tile unique for every tile, which can lead to ANRs */
     val placeholderText = text.getPlaceholderText()
     val params = text.getPlaceholderParameters()
-    val type = UniqueType.values().firstOrNull { it.placeholderText == placeholderText }
+    val type = UniqueType.uniqueTypeMap[placeholderText]
 
     val stats: Stats by lazy {
         val firstStatParam = params.firstOrNull { Stats.isStats(it) }
@@ -30,9 +30,11 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
     }
     val conditionals: List<Unique> = text.getConditionals()
 
-    val isTriggerable = type != null && type.targetTypes.contains(UniqueTarget.Triggerable)
-            // <for [amount] turns]> in effect makes any unique become a triggerable unique
+    val isTriggerable = type != null && (
+        type.targetTypes.contains(UniqueTarget.Triggerable)
+            || type.targetTypes.contains(UniqueTarget.UnitTriggerable)
             || conditionals.any { it.type == UniqueType.ConditionalTimedUnique }
+        )
 
     val allParams = params + conditionals.flatMap { it.params }
 
@@ -41,7 +43,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
     fun hasFlag(flag: UniqueFlag) = type != null && type.flags.contains(flag)
 
     fun hasTriggerConditional(): Boolean {
-        if(conditionals.none()) return false
+        if (conditionals.none()) return false
         return conditionals.any { conditional ->
             conditional.type?.targetTypes?.any {
                 it.canAcceptUniqueTarget(UniqueTarget.TriggerCondition) || it.canAcceptUniqueTarget(UniqueTarget.UnitActionModifier)
@@ -117,7 +119,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
         // filter out possible replacements that are obviously wrong
         val uniquesWithNoErrors = finalPossibleUniques.filter {
             val unique = Unique(it)
-            val errors = RulesetValidator(ruleset).checkUnique(
+            val errors = UniqueValidator(ruleset).checkUnique(
                 unique, true, null,
                 UniqueType.UniqueComplianceErrorSeverity.RulesetSpecific
             )
@@ -247,7 +249,10 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
                 state.ourCombatant != null && state.ourCombatant.getHealth() < condition.params[0].toInt()
             UniqueType.ConditionalHasNotUsedOtherActions ->
                 state.unit != null &&
+                    // OLD format
                 state.unit.run { limitedActionsUnitCanDo().all { abilityUsesLeft[it] == maxAbilityUses[it] } }
+                    // NEW format
+                    && state.unit.abilityToTimesUsed.isEmpty()
 
             UniqueType.ConditionalInTiles ->
                 relevantTile?.matchesFilter(condition.params[0], state.civInfo) == true
