@@ -3,20 +3,22 @@ package com.unciv.ui.popups.options
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.unciv.GUI
 import com.unciv.UncivGame
-import com.unciv.logic.files.UncivFiles
 import com.unciv.logic.files.MapSaver
+import com.unciv.logic.files.UncivFiles
 import com.unciv.models.ruleset.RulesetCache
 import com.unciv.models.ruleset.tile.ResourceType
-import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.components.UncivSlider
 import com.unciv.ui.components.UncivTextField
-import com.unciv.ui.components.extensions.onClick
 import com.unciv.ui.components.extensions.toCheckBox
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.ui.components.input.onClick
+import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.utils.DebugUtils
 
-fun debugTab() = Table(BaseScreen.skin).apply {
+fun debugTab(
+    optionsPopup: OptionsPopup
+) = Table(BaseScreen.skin).apply {
     pad(10f)
     defaults().pad(5f)
     val game = UncivGame.Current
@@ -59,6 +61,7 @@ fun debugTab() = Table(BaseScreen.skin).apply {
     add("Enable espionage option".toCheckBox(game.settings.enableEspionageOption) {
         game.settings.enableEspionageOption = it
     }).colspan(2).row()
+
     add("Save games compressed".toCheckBox(UncivFiles.saveZipped) {
         UncivFiles.saveZipped = it
     }).colspan(2).row()
@@ -66,14 +69,17 @@ fun debugTab() = Table(BaseScreen.skin).apply {
         MapSaver.saveZipped = it
     }).colspan(2).row()
 
+    if (GUI.keyboardAvailable) {
+        add("Show keyboard bindings".toCheckBox(optionsPopup.enableKeyBindingsTab) {
+            optionsPopup.enableKeyBindingsTab = it
+            optionsPopup.showOrHideKeyBindings()
+        }).colspan(2).row()
+    }
+
     add("Gdx Scene2D debug".toCheckBox(BaseScreen.enableSceneDebug) {
         BaseScreen.enableSceneDebug = it
     }).colspan(2).row()
 
-    add("Allow untyped Uniques in mod checker".toCheckBox(RulesetCache.modCheckerAllowUntypedUniques) {
-        RulesetCache.modCheckerAllowUntypedUniques = it
-    }).colspan(2).row()
-
     add(Table().apply {
         add("Unique misspelling threshold".toLabel()).left().fillX()
         add(
