@@ -2,24 +2,24 @@ package com.unciv.ui.screens.worldscreen.unit
 
 import com.badlogic.gdx.Gdx
 import com.badlogic.gdx.Input
+import com.badlogic.gdx.graphics.Color
 import com.badlogic.gdx.scenes.scene2d.Actor
 import com.badlogic.gdx.scenes.scene2d.Touchable
 import com.badlogic.gdx.scenes.scene2d.ui.Image
 import com.badlogic.gdx.scenes.scene2d.ui.Table
-import com.badlogic.gdx.scenes.scene2d.ui.VerticalGroup
 import com.unciv.Constants
 import com.unciv.logic.battle.CityCombatant
 import com.unciv.logic.city.City
 import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.tile.Tile
-import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.translations.tr
 import com.unciv.ui.components.UnitGroup
 import com.unciv.ui.components.extensions.addSeparator
 import com.unciv.ui.components.extensions.center
 import com.unciv.ui.components.extensions.darken
-import com.unciv.ui.components.extensions.onClick
+import com.unciv.ui.components.extensions.toImageButton
 import com.unciv.ui.components.extensions.toLabel
+import com.unciv.ui.components.input.onClick
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.civilopediascreen.CivilopediaCategories
@@ -58,7 +58,6 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
     }
 
     var selectedCity : City? = null
-    private val deselectUnitButton = Table()
 
     // This is so that not on every update(), we will update the unit table.
     // Most of the time it's the same unit with the same stats so why waste precious time?
@@ -81,20 +80,13 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
 
         promotionsTable.touchable = Touchable.enabled
 
-        add(VerticalGroup().apply {
-            pad(5f)
-            touchable = Touchable.enabled
-            onClick {
-                selectUnit()
-                worldScreen.shouldUpdate = true
-                this@UnitTable.isVisible = false
-            }
-
-            deselectUnitButton.add(ImageGetter.getImage("OtherIcons/Close")).size(20f).pad(10f)
-            deselectUnitButton.pack()
-            deselectUnitButton.touchable = Touchable.enabled
-            addActor(deselectUnitButton)
-        }).left()
+        val deselectUnitButton = "OtherIcons/Close".toImageButton(20f, 50f, Color.CLEAR, Color.RED)
+        deselectUnitButton.onClick {
+            selectUnit()
+            worldScreen.shouldUpdate = true
+            this@UnitTable.isVisible = false
+        }
+        add(deselectUnitButton).left()
 
         add(Table().apply {
             val moveBetweenUnitsTable = Table().apply {
@@ -106,10 +98,10 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
                 add(unitIconNameGroup)
                 add(nextIdleUnitButton)
             }
-            add(moveBetweenUnitsTable).colspan(2).fill().row()
+            add(moveBetweenUnitsTable).fill().row()
 
-            separator = addSeparator().actor!!
-            add(promotionsTable).colspan(2).row()
+            separator = addSeparator().padBottom(5f).actor!!
+            add(promotionsTable).row()
             add(unitDescriptionTable)
             touchable = Touchable.enabled
             onClick {
@@ -192,7 +184,7 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
                 }
 
                 if (!unit.isCivilian()) {
-                    unitDescriptionTable.add("XP".tr().toLabel().apply {
+                    unitDescriptionTable.add("XP".toLabel().apply {
                         onClick {
                             if (selectedUnit == null) return@onClick
                             worldScreen.game.pushScreen(PromotionPickerScreen(unit))
@@ -262,13 +254,14 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
         unitIconHolder.clear()
         promotionsTable.clear()
         unitDescriptionTable.clearListeners()
+        separator.width = 0f  // ImageWithCustomSize remembers width and returns if when Table asks for prefWidth
 
         if (selectedUnit != null) {
             if (selectedUnits.size == 1) { // single selected unit
                 unitIconHolder.add(UnitGroup(selectedUnit!!, 30f)).pad(5f)
 
                 for (promotion in selectedUnit!!.promotions.getPromotions(true))
-                    promotionsTable.add(ImageGetter.getPromotionPortrait(promotion.name))
+                    promotionsTable.add(ImageGetter.getPromotionPortrait(promotion.name)).padBottom(2f)
 
                 // Since Clear also clears the listeners, we need to re-add them every time
                 promotionsTable.onClick {
@@ -319,14 +312,20 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
 
         fun MapUnit.isEligible(): Boolean = (this.civ == worldScreen.viewingCiv
                 || worldScreen.viewingCiv.isSpectator()) && this !in selectedUnits
-        fun MapUnit.isPrioritized(): Boolean = this.isGreatPerson() || this.hasUnique(UniqueType.FoundCity)
 
-        // Civ 5 Order of selection:
+        // This is the Civ 5 Order of selection:
         // 1. City
         // 2. GP + Settlers
         // 3. Military
         // 4. Other civilian (Workers)
         // 5. None (Deselect)
+        // However we deviate from it because there was a poll on Discord that clearly showed that
+        // people would prefer the military unit to always be preferred over GP, so we use this:
+        // 1. City
+        // 2. Military
+        // 3. GP + Settlers
+        // 4. Other civilian (Workers)
+        // 5. None (Deselect)
 
         val civUnit = selectedTile.civilianUnit
         val milUnit = selectedTile.militaryUnit
@@ -334,7 +333,6 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
 
         val nextUnit: MapUnit?
         val priorityUnit = when {
-            civUnit != null && civUnit.isEligible() && civUnit.isPrioritized() -> civUnit
             milUnit != null && milUnit.isEligible() -> milUnit
             civUnit != null && civUnit.isEligible() -> civUnit
             else -> null
@@ -342,8 +340,8 @@ class UnitTable(val worldScreen: WorldScreen) : Table() {
 
         nextUnit = when {
                 curUnit == null -> priorityUnit
-                curUnit == civUnit && milUnit != null && milUnit.isEligible() -> {if (civUnit.isPrioritized()) milUnit else null}
-                curUnit == milUnit && civUnit != null && civUnit.isEligible() -> {if (civUnit.isPrioritized()) null else civUnit}
+                curUnit == civUnit && milUnit != null && milUnit.isEligible() -> null
+                curUnit == milUnit && civUnit != null && civUnit.isEligible() -> civUnit
                 else -> priorityUnit
             }
 
